Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.injectHelpers = void 0;

const injectHelpers = async page => {
  await page.evaluate(() => {
    const getReactName = el => {
      let reactName = null;
      const key = Object.keys(el).find(key => key.startsWith('__reactFiber$'));

      if (typeof key === 'string') {
        const {
          elementType
        } = el[key].return;

        if (typeof elementType === 'string') {
          reactName = elementType;
        } else if (typeof elementType.displayName === 'string') {
          reactName = elementType.displayName;
        }
      }

      return reactName;
    };

    window.r11y = {
      getReactName,

      getReactPath(el) {
        const reactName = getReactName(el);
        const parentReactName = getReactName(el.parentNode);
        let reactPath = null;

        if (reactName !== null) {
          reactPath = reactName;

          if (parentReactName !== null) {
            reactPath = `${parentReactName} > ${reactPath}`;
          }
        }

        return reactPath;
      },

      getAttrs(el) {
        return Array.from(el.attributes).reduce((attrs, attr) => {
          if (attr.name === 'type' || attr.name === 'role' || attr.name.startsWith('aria-')) {
            attrs[attr.name] = attr.value;
          }

          return attrs;
        }, {});
      }

    };
  });
};

exports.injectHelpers = injectHelpers;